aboutsummaryrefslogtreecommitdiffstats
path: root/include/queue_fn.php
diff options
context:
space:
mode:
Diffstat (limited to 'include/queue_fn.php')
-rw-r--r--include/queue_fn.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/queue_fn.php b/include/queue_fn.php
index 3112a832b..676620e2f 100644
--- a/include/queue_fn.php
+++ b/include/queue_fn.php
@@ -126,7 +126,7 @@ function queue_deliver($outq, $immediate = false) {
remove_queue_item($outq['outq_hash']);
// server is responding - see if anything else is going to this destination and is piled up
// and try to send some more. We're relying on the fact that delivery_loop() results in an
// immediate delivery otherwise we could get into a queue loop.
if(! $immediate) {
@@ -141,7 +141,7 @@ function queue_deliver($outq, $immediate = false) {
}
}
if($piled_up) {
- delivery_loop($piled_up);
+ do_delivery($piled_up);
}
}
}
@@ -126,7 +126,7 @@ function queue_deliver($outq, $immediate = false) {
remove_queue_item($outq['outq_hash']);
// server is responding - see if anything else is going to this destination and is piled up
- // and try to send some more. We're relying on the fact that delivery_loop() results in an
+ // and try to send some more. We're relying on the fact that do_delivery() results in an
// immediate delivery otherwise we could get into a queue loop.
if(! $immediate) {